@@ -61,9 +61,9 @@ def run_symilar(argv: Sequence[str] | None = None) -> NoReturn:
 
     argv can be a sequence of strings normally supplied as arguments on the command line
     """
-    from pylint.checkers.similar import Run as SimilarRun
+    from pylint.checkers.symilar import Run as SymilarRun
 
-    SimilarRun(argv or sys.argv[1:])
+    SymilarRun(argv or sys.argv[1:])
 
 
 def modify_sys_path() -> None:
